==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'İstatistikleri sil', # MODIF

	// I
	'icone_evolution_visites' => 'Ziyaretlerin gelişimi<br /> @visites@ ziyaret',
	'icone_repartition_actuelle' => 'Mevcut dağılımı göster',
	'icone_repartition_visites' => 'Ziyaretlerin dağılımı',
	'icone_statistiques_visites' => 'İstatistikler',
	'info_affichier_visites_articles_plus_visites' => '<b>Başlangıçtan beri en çok ziyaret edilen makaleleri</b> göster :',
	'info_comment_lire_tableau' => 'Bu tabloyu nasıl okumalı ?',
	'info_forum_statistiques' => 'Ziyaret istatistikleri',
	'info_popularite_2' => 'Sitenin popülerliği',
	'info_popularite_3' => 'popülerlik : @popularite@ ; ziyaretler : @visites@',
	'info_popularite_5' => 'Popülerlik  ',
	'info_question_vignettes_referer' => 'İstatistikleri incelediğinizde, ziyaretlerin yapıldığı kaynak sitelerden görüntüler görebilirsiniz',
	'info_question_vignettes_referer_oui' => 'Ziyaretlerin yapıldığı kaynak sitelerden görüntüler göster',
	'info_visites' => 'Ziyaret :',
	'info_visites_plus_populaires' => '<b>En popüler makaleler</b> ile <b>yayınlanan son makalelere</b> yapılan ziyaretleri görüntüle.',
	'info_zoom' => 'yakınlaştır',
	'item_gerer_statistiques' => 'İstatistikleri yönet', # MODIF

	// O
	'onglet_origine_visites' => 'Ziyaretlerin kaynağı',
	'onglet_repartition_debut' => 'Başlangıçtan beri',
	'onglet_repartition_lang' => 'Dillere göre dağılım',

	// T
	'texte_admin_effacer_stats' => 'Bu komut, site ziyareti istatistiklerine bağlı tüm bilgileri siler (makalelerin popülerlikleri de dahil).',
	'texte_comment_lire_tableau' => 'Popülerlik sınıflandırmasında makalenin sırası kenarda belirtilmiştir ; makalenin popülerliği (şimdiki başvuru sıklığı devam ettiği takdirde, geleceği tahmin edilen günlük ziyaretçi sayısı) ve başından beri gelen ziyaretçi sayısı, fare başlık üzerinden geçtiğinde ortaya çıkan konuşma balonunun içinde görüntülenir.',
	'texte_signification' => 'Koyu çizgiler, toplam girişleri (alt-bölümlerin toplamını), açık çizgiler ise, her bir bölüme gelen ziyaret sayısını temsil eder.',
	'titre_evolution_visite' => 'Ziyaretlerin gelişimi ',
	'titre_liens_entrants' => 'Giren bağlantılar',
	'titre_page_statistiques' => 'Bölümlere göre istatistikler ',
	'titre_page_statistiques_visites' => 'Ziyaret istatistikleri'
);

==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'İstatistikleri sil', # MODIF

	// I
	'icone_evolution_visites' => 'Ziyaretlerin gelişimi<br /> @visites@ ziyaret',
	'icone_repartition_actuelle' => 'Mevcut dağılımı göster',
	'icone_repartition_visites' => 'Ziyaretlerin dağılımı',
	'icone_statistiques_visites' => 'İstatistikler',
	'info_affichier_visites_articles_plus_visites' => '<b>Başlangıçtan beri en çok ziyaret edilen makaleleri</b> göster :',
	'info_comment_lire_tableau' => 'Bu tabloyu nasıl okumalı ?',
	'info_forum_statistiques' => 'Ziyaret istatistikleri',
	'info_popularite_2' => 'Sitenin popülerliği',
	'info_popularite_3' => 'popülerlik : @popularite@ ; ziyaretler : @visites@',
	'info_popularite_5' => 'Popülerlik  ',
	'info_question_vignettes_referer' => 'İstatistikleri incelediğinizde, ziyaretlerin yapıldığı kaynak sitelerden görüntüler görebilirsiniz', # MODIF
	'info_question_vignettes_referer_oui' => 'Ziyaretlerin yapıldığı kaynak sitelerden görüntüler göster',
	'info_visites' => 'Ziyaret :',
	'info_visites_plus_populaires' => '<b>En popüler makaleler</b> ile <b>yayınlanan son makalelere</b> yapılan ziyaretleri görüntüle.',
	'info_zoom' => 'yakınlaştır',
	'item_gerer_statistiques' => 'İstatistikleri yönet', # MODIF

	// O
	'onglet_origine_visites' => 'Ziyaretlerin kaynağı',
	'onglet_repartition_debut' => 'Başlangıçtan beri',
	'onglet_repartition_lang' => 'Dillere göre dağılım',

	// T
	'texte_admin_effacer_stats' => 'Bu komut, site ziyareti istatistiklerine bağlı tüm bilgileri siler (makalelerin popülerlikleri de dahil).',
	'texte_comment_lire_tableau' => 'Popülerlik sınıflandırmasında makalenin sırası kenarda belirtilmiştir ; makalenin popülerliği (şimdiki başvuru sıklığı devam ettiği takdirde, geleceği tahmin edilen günlük ziyaretçi sayısı) ve başından beri gelen ziyaretçi sayısı, fare başlık üzerinden geçtiğinde ortaya çıkan konuşma balonunun içinde görüntülenir.',
	'texte_signification' => 'Koyu çizgiler, toplam girişleri (alt-bölümlerin toplamını), açık çizgiler ise, her bir bölüme gelen ziyaret sayısını temsil eder.',
	'titre_evolution_visite' => 'Ziyaretlerin gelişimi ',
	'titre_liens_entrants' => 'Giren bağlantılar',
	'titre_page_statistiques' => 'Bölümlere göre istatistikler ',
	'titre_page_statistiques_visites' => 'Ziyaret istatistikleri'
);
